@@ -1,7 +1,7 @@
 #' Compute sum/mean/sd/median/max/min/custom function on rows/columns 
 #' 
-#' These functions are intended for usage inside \link{compute}, and
-#' \link{do_if}. sum/mean/sd/median/max/min by default omits NA. \code{any_in_*}
+#' These functions are intended for usage inside \link[maditr]{let}, and
+#' \link[maditr]{let_if}. sum/mean/sd/median/max/min by default omits NA. \code{any_in_*}
 #' checks existence of any TRUE in each row/column. It is equivalent of
 #' \link[base]{any} applied to each row/column. \code{all_in_*} is equivalent of
 #' \link[base]{all} applied to each row/column.
@@ -18,16 +18,17 @@
 #'   equals the number of argument columns/rows. Value of \code{apply_*} depends
 #'   on supplied \code{fun} function.
 #' 
-#' @seealso \link{compute}, \link{do_if}, \link{\%to\%}, \link{count_if},
+#' @seealso \link{\%to\%}, \link{count_if},
 #'   \link{sum_if}, \link{mean_if}, \link{median_if}, \link{sd_if},
 #'   \link{min_if}, \link{max_if}
 #' 
 #' @export
 #' @examples
-#' iris = compute(iris, {
-#'   new_median = median_row(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
-#'   new_mean = mean_row(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
-#'   })
+#' iris = iris %>% 
+#'     let( 
+#'         new_median = median_row(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width),
+#'         new_mean = mean_row(Sepal.Length, Sepal.Width, Petal.Length, Petal.Width)
+#'     )
 #'   
 #' dfs = data.frame(
 #'     test = 1:5,
@@ -40,16 +41,19 @@
 #' )
 #' 
 #' # calculate sum of b* variables
-#' compute(dfs, {
-#'     b_total = sum_row(b_, b_1 %to% b_5)
-#' })
+#' dfs %>% 
+#'     let( 
+#'         b_total = sum_row(b_, b_1 %to% b_5)
+#'     ) %>% 
+#'     print()
 #' 
 #' # conditional modification
-#' do_if(dfs, test %in% 2:4, {
-#'     b_total = sum_row(b_, b_1 %to% b_5)
-#' })
+#' dfs %>% 
+#'     let_if(test %in% 2:4, 
+#'         b_total = sum_row(b_, b_1 %to% b_5)
+#'     ) %>% 
+#'     print()
 #' 
-
 #' 
 #' @export
 sum_row=function(..., na.rm = TRUE){
@@ -194,7 +198,7 @@ apply_row = function(fun, ...){
         fun(data[each_row, ])
     })
     if(any(lengths(res) != 1)){
-        stop("'apply_col': incorrect result - function returns values with length greater than one.")    
+        stop("'apply_row': incorrect result - function returns values with length greater than one.")    
     }
     unlist(res, use.names = FALSE, recursive = TRUE)
 }
